import java.util.ArrayList;
import java.util.HashMap;
import java.util.Scanner;
import java.io.*;

class Tbaneplanlegger {
    public static void main(String[] arg) throws Exception {
	Stasjonsoversikt stasjonsliste = new Stasjonsoversikt();
	Linje[] linjer = new Linje[6+1];
	linjer[1] = new Linje(1, "frognerseterbanen.text");
	linjer[2] = new Linje(2, "kolsaasbanen.text");
	linjer[3] = new Linje(3, "skullerudbanen.text");
	linjer[4] = new Linje(4, "lambertseterbanen.text");
	linjer[5] = new Linje(5, "roeabanen.text");
	linjer[6] = new Linje(6, "sognsvannsbanen.text");
	for (int i = 1;  i <= 6;  i++) {
	    linjer[i].init(stasjonsliste);
	}

	if (arg.length != 2) {
	    System.out.println("Usage: java Tbaneplanlegger fra-stasjon til-stasjon");
	    System.exit(1);
	}

	if (! stasjonsliste.finnes(arg[0])) {
	    System.out.println("Stasjonen " + arg[0] + " finnes ikke!");
	    System.exit(2);
	}
	Stasjon fraStasjon = stasjonsliste.finn(arg[0]);

	if (! stasjonsliste.finnes(arg[1])) {
	    System.out.println("Stasjonen " + arg[1] + " finnes ikke!");
	    System.exit(2);
	}
	Stasjon tilStasjon = stasjonsliste.finn(arg[1]);

	if (fraStasjon.finnesDirekteReise(tilStasjon)) {
	    System.out.println("Det er direkte reise fra " + fraStasjon +
	        " til " + tilStasjon);
	} else {
	    Stasjon overgang = fraStasjon.finnReiseMedOvergang(tilStasjon);
	    if (overgang != null) {
		System.out.println("Du kommer fra " + fraStasjon +
		    " til " + tilStasjon + " ved bytte paa " + overgang);
	    } else {
		System.out.println("Ingen reise fra " + fraStasjon + 
		    " til " + tilStasjon);
	    }
	}
    }
}


class Linje {
    private int linjenr;
    private String stasjonsfilnavn;
    private ArrayList<Stasjon> stasjoner = new ArrayList<>();

    Linje(int nr, String filnavn) {
	linjenr = nr;  stasjonsfilnavn = filnavn;
    }

    void init(Stasjonsoversikt alleStasjoner) throws Exception {
	File f = new File(stasjonsfilnavn);
	Scanner s = new Scanner(f);
	while (s.hasNextLine()) {
	    String navn = s.nextLine();
	    Stasjon denneStasjon = alleStasjoner.finn(navn);
	    stasjoner.add(denneStasjon);
	    denneStasjon.erPaaLinje(this);
	}
	s.close();
    }

    boolean passerer(Stasjon s) {
	for (int i = 0;  i < stasjoner.size();  i++) {
	    if (stasjoner.get(i) == s) {
		return true;
	    }
	}
	return false;
    }

    Stasjon finnOvergangTil(Stasjon s) {
	for (int i = 0;  i < stasjoner.size();  i++) {
	    Stasjon sx = stasjoner.get(i);
	    if (sx.finnesDirekteReise(s)) {
		return sx;
	    }
	}
	return null;
    }
}


class Stasjonsoversikt {
    private HashMap<String,Stasjon> oversikt = new HashMap<>();

    Stasjon finn(String stasjonsnavn) {
	Stasjon s = oversikt.get(stasjonsnavn);
	if (s == null) {
	    s = new Stasjon(stasjonsnavn);
	    oversikt.put(stasjonsnavn, s);
	}
	return s;
    }

    boolean finnes(String stasjonsnavn) {
	return oversikt.get(stasjonsnavn) != null;
    }
}


class Stasjon {
    private String navn;
    private ArrayList<Linje> linjer = new ArrayList<>();

    Stasjon(String n) {
	navn = n;
    }

    public String toString() {
	return navn;
    }

    void erPaaLinje(Linje denneLinje) {
	linjer.add(denneLinje);
    }

    boolean finnesDirekteReise(Stasjon til) {
	for (int i = 0;  i < linjer.size();  i++) {
	    if (linjer.get(i).passerer(til)) {
		return true;
	    }
	}
	return false;
    }

    Stasjon finnReiseMedOvergang(Stasjon til) {
	for (int i = 0;  i < linjer.size();  i++) {
	    Stasjon s = linjer.get(i).finnOvergangTil(til);
	    if (s != null) {
		return s;
	    }
	}
	return null;
    }
}
